<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>AllFields</name>
    <message>
        <location filename="../details.cpp" line="653"/>
        <source>Field</source>
        <translation>Camp</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="653"/>
        <source>Field name</source>
        <translation>Nom del camp</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="654"/>
        <source>Description</source>
        <translation>Descripció</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="654"/>
        <source>Field description</source>
        <translation>Descripció del camp</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="655"/>
        <source>Value</source>
        <translation>Valor</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="655"/>
        <source>Field value</source>
        <translation>Valor del camp</translation>
    </message>
</context>
<context>
    <name>Boxvar</name>
    <message>
        <location filename="../prefs.cpp" line="59"/>
        <source>Exit on closing</source>
        <translation>Surt en tancar</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="60"/>
        <source>Remember Position</source>
        <translation>Recorda la posició</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="68"/>
        <source>Host Name Lookup</source>
        <translation>Recerca del nom d&apos;amfitrió</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="69"/>
        <source>Service Name Lookup</source>
        <translation>Recerca del nom de servei</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="75"/>
        <source>Disclosure Triangles</source>
        <translation>Triangles de divulgació</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="76"/>
        <source>Branch Lines</source>
        <translation>Línies de bifurcació</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="82"/>
        <source>Auto Save Settings on Exit</source>
        <translation>Desa automàticament els ajusts en sortir</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="83"/>
        <source>Selection: Copy PIDs to Clipboard</source>
        <translation>Selecció: copia els PID al porta-retalls</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="85"/>
        <source>Normalize NICE</source>
        <translation>Normalitza NICE</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="86"/>
        <source>Use pmap for Map Names</source>
        <translation>Utilitza pmap per al mapatge dels noms</translation>
    </message>
</context>
<context>
    <name>Cbgroup</name>
    <message>
        <location filename="../prefs.cpp" line="106"/>
        <source>General</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Command</name>
    <message>
        <location filename="../command.cpp" line="208"/>
        <source>The command:

</source>
        <translation>L&apos;ordre:

</translation>
    </message>
    <message>
        <location filename="../command.cpp" line="212"/>
        <source>

failed with the error:

</source>
        <translation>

ha fallat amb l&apos;error:

</translation>
    </message>
    <message>
        <location filename="../command.cpp" line="215"/>
        <source>Too many processes</source>
        <translation>Hi ha massa processos</translation>
    </message>
    <message>
        <location filename="../command.cpp" line="218"/>
        <source>Unknown error</source>
        <translation>Error desconegut</translation>
    </message>
    <message>
        <location filename="../command.cpp" line="228"/>
        <source>

could not be executed because it was not found,
or you did not have execute permission.</source>
        <translation>

no s&apos;ha pogut executar perquè no s&apos;ha trobat,
o no teniu permisos d&apos;execució.</translation>
    </message>
    <message>
        <location filename="../command.cpp" line="233"/>
        <source>

exited with status </source>
        <translation>

ha sortit amb l&apos;estat </translation>
    </message>
    <message>
        <location filename="../command.cpp" line="237"/>
        <source>Command Failed</source>
        <translation>Ordre fallida</translation>
    </message>
</context>
<context>
    <name>CommandDialog</name>
    <message>
        <location filename="../commanddialog.cpp" line="47"/>
        <source>Edit Commands 0.1 alpha</source>
        <translation>Editor d&apos;ordres 0.1 alfa</translation>
    </message>
    <message>
        <location filename="../commanddialog.cpp" line="63"/>
        <source>Name:</source>
        <translation>Nom:</translation>
    </message>
    <message>
        <location filename="../commanddialog.cpp" line="79"/>
        <source>Popup</source>
        <translation>Emergent</translation>
    </message>
    <message>
        <location filename="../commanddialog.cpp" line="84"/>
        <source>Command Line:</source>
        <translation>Línia d&apos;ordres:</translation>
    </message>
    <message>
        <location filename="../commanddialog.cpp" line="95"/>
        <source>Substitutions:
%p	PID
%c	COMMAND
%C	CMDLINE
%u	USER
%%	%

</source>
        <translation>Substitucions:
%p	PID
%c	ORDRE
%C	LÍNIA_ORDRES
%u	USUARI
%%	%

</translation>
    </message>
    <message>
        <location filename="../commanddialog.cpp" line="109"/>
        <source>New...</source>
        <translation>Nou...</translation>
    </message>
    <message>
        <location filename="../commanddialog.cpp" line="111"/>
        <location filename="../commanddialog.cpp" line="229"/>
        <source>Add...</source>
        <translation>Afegeix...</translation>
    </message>
    <message>
        <location filename="../commanddialog.cpp" line="113"/>
        <source>Delete</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../commanddialog.cpp" line="115"/>
        <source>Close</source>
        <translation>Tanca</translation>
    </message>
</context>
<context>
    <name>ControlBar</name>
    <message>
        <location filename="../misc.cpp" line="758"/>
        <source>Linear</source>
        <translation>Lineal</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="761"/>
        <source>Tree</source>
        <translation>Arbre</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="770"/>
        <source>Thread</source>
        <translation>Fil</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="777"/>
        <source>All Processes</source>
        <translation>Tots els processos</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="778"/>
        <source>Your Processes</source>
        <translation>Els vostres processos</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="779"/>
        <source>Non-Root Processes</source>
        <translation>Els processos que no siguin de root</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="780"/>
        <source>Running Processes</source>
        <translation>Els processos en execució</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="796"/>
        <source>Pause (Ctrl+Space)</source>
        <translation>Pausa (Ctrl+Espai)</translation>
    </message>
</context>
<context>
    <name>Details</name>
    <message>
        <location filename="../details.cpp" line="36"/>
        <source>Process %1 ( %2 ) - details</source>
        <translation>Procés %1 ( %2 ) - detalls</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="45"/>
        <source>Files</source>
        <translation>Fitxers</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="54"/>
        <source>Sockets</source>
        <translation>Sòcols</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="59"/>
        <source>Memory Maps</source>
        <translation>Mapatges de memòria</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="61"/>
        <source>Environment</source>
        <translation>Entorn</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="62"/>
        <source>All Fields</source>
        <translation>Tots els camps</translation>
    </message>
</context>
<context>
    <name>Environ</name>
    <message>
        <location filename="../details.cpp" line="605"/>
        <source>Variable</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../details.cpp" line="605"/>
        <source>Variable name</source>
        <translation>Nom de la variable</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="606"/>
        <source>Value</source>
        <translation>Valor</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="606"/>
        <source>Variable value</source>
        <translation>Valor de la variable</translation>
    </message>
</context>
<context>
    <name>EventDialog</name>
    <message>
        <location filename="../watchdog.ui" line="23"/>
        <source>Watchdog 0.1 alpha</source>
        <translation>Vigilant 0.1 alfa</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="117"/>
        <source>Eventcat</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="162"/>
        <source>Select condition</source>
        <translation>Condició de selecció</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="170"/>
        <source>labelDescrition</source>
        <translation>Descripció</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="193"/>
        <source>Enable</source>
        <translation>Habilita</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="219"/>
        <source>process name</source>
        <translation>nom del procés</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="229"/>
        <source>cpu</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="248"/>
        <source>%</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="280"/>
        <source>include already running process</source>
        <translation>inclou el procés que ja s&apos;està executant</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="309"/>
        <source>run command</source>
        <translation>executa l&apos;ordre</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="342"/>
        <source>show Message</source>
        <translation>mostra el missatge</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="367"/>
        <source>Help (Not yet. just concept)</source>
        <translation>Ajuda (encara no. tan sols el concepte)</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="394"/>
        <source>%p : pid
%c : command</source>
        <translation>%p : pid
%c : ordre</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="425"/>
        <source>New</source>
        <translation>Nou</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="432"/>
        <source>Add</source>
        <translation>Afegeix</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="439"/>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <location filename="../watchdog.ui" line="446"/>
        <source>Close</source>
        <translation>Tanca</translation>
    </message>
</context>
<context>
    <name>ExecWindow</name>
    <message>
        <location filename="../message.ui" line="13"/>
        <source>Qps</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../message.ui" line="27"/>
        <source>Ok</source>
        <translation>D&apos;acord</translation>
    </message>
    <message>
        <location filename="../execwindow.cpp" line="42"/>
        <source>Qps Watchdog</source>
        <translation>Vigilant de Qps</translation>
    </message>
    <message>
        <location filename="../execwindow.cpp" line="95"/>
        <source>%1 exit with code %2</source>
        <translation>%1 surt amb el codi %2</translation>
    </message>
    <message>
        <location filename="../execwindow.cpp" line="97"/>
        <source>Close</source>
        <translation>Tanca</translation>
    </message>
    <message>
        <location filename="../execwindow.cpp" line="103"/>
        <source>%1 [running]</source>
        <translation>%1 [en execució]</translation>
    </message>
    <message>
        <location filename="../execwindow.cpp" line="104"/>
        <source>terminate command</source>
        <translation>finalitza l&apos;ordre</translation>
    </message>
    <message>
        <location filename="../execwindow.cpp" line="113"/>
        <source>Error %1 : [%2] Maybe command not found</source>
        <translation>Error %1 : [%2] Potser no s&apos;ha trobat l&apos;ordre</translation>
    </message>
</context>
<context>
    <name>FieldSelect</name>
    <message>
        <location filename="../fieldsel.cpp" line="34"/>
        <source>Select Custom Fields </source>
        <translation>Selecció dels camps personalitzats </translation>
    </message>
    <message>
        <location filename="../fieldsel.cpp" line="75"/>
        <source>Close</source>
        <translation>Tanca</translation>
    </message>
</context>
<context>
    <name>Files</name>
    <message>
        <location filename="../details.cpp" line="521"/>
        <source>Fd</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../details.cpp" line="521"/>
        <source>File descriptor</source>
        <translation>Descriptor de fitxer</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="523"/>
        <source>Mode</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../details.cpp" line="523"/>
        <source>Open mode</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../details.cpp" line="525"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="525"/>
        <source>File name (if available)</source>
        <translation>Nom de fitxer (si està disponible)</translation>
    </message>
</context>
<context>
    <name>IntervalDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="43"/>
        <source>Change Update Period</source>
        <translation>Canvi del període d&apos;actualització</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="49"/>
        <source>New Update Period</source>
        <translation>Període d&apos;actualització nou</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="85"/>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="87"/>
        <source>OK</source>
        <translation>D&apos;acord</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="121"/>
        <source>No UPDATE</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="139"/>
        <source>Invalid value</source>
        <translation>Valor no vàlid</translation>
    </message>
</context>
<context>
    <name>ListModel</name>
    <message>
        <location filename="../listmodel.cpp" line="66"/>
        <source>Event Category</source>
        <translation>Categoria d&apos;esdeveniment</translation>
    </message>
    <message>
        <location filename="../listmodel.cpp" line="68"/>
        <source>Enable</source>
        <translation>Habilita</translation>
    </message>
</context>
<context>
    <name>Maps</name>
    <message>
        <location filename="../details.cpp" line="392"/>
        <source>Address Range</source>
        <translation>Interval d&apos;adreces</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="392"/>
        <source>Mapped addresses (hex) )</source>
        <translation>Adreces assignades (hex) )</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="393"/>
        <source>Size</source>
        <translation>Mida</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="393"/>
        <source>Kbytes mapped (dec)</source>
        <translation>Kbytes assignats (dec)</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="394"/>
        <source>Perm</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../details.cpp" line="394"/>
        <source>Permission flags</source>
        <translation>Indicadors dels permisos</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="395"/>
        <source>Offset</source>
        <translation>Desplaçament</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="395"/>
        <source>File offset at start of mapping (hex)</source>
        <translation>Desplaçament de fitxer al començament del mapatge (hex)</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="396"/>
        <source>Device</source>
        <translation>Dispositiu</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="396"/>
        <source>Major,Minor device numbers (dec)</source>
        <translation>Nombres de dispositius major,menor (dec)</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="397"/>
        <source>Inode</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../details.cpp" line="397"/>
        <source>Inode number (dec)</source>
        <translation>Nombre d&apos;inode (dec)</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="398"/>
        <source>File</source>
        <translation>Fitxer</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="398"/>
        <source>File name (if available)</source>
        <translation>Nom de fitxer (si està disponible)</translation>
    </message>
</context>
<context>
    <name>PermissionDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="264"/>
        <source>Permission</source>
        <translation>Permisos</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="273"/>
        <source>Root password</source>
        <translation>Contrasenya de root</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="280"/>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="283"/>
        <source>OK</source>
        <translation>D&apos;acord</translation>
    </message>
</context>
<context>
    <name>Preferences</name>
    <message>
        <location filename="../prefs.cpp" line="150"/>
        <source>Preferences</source>
        <translation>Preferències</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="157"/>
        <source>Setting</source>
        <translation>Establiment</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="191"/>
        <source>%CPU divided by</source>
        <translation>%CPU dividida per</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="198"/>
        <source>Total cpu: %1</source>
        <translation>cpu total: %1</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="199"/>
        <source>Single cpu: 1</source>
        <translation>cpu individual: 1</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="205"/>
        <source>default</source>
        <translation>per defecte</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="206"/>
        <source>for developer</source>
        <translation>per al desenvolupador</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="240"/>
        <source>Appearance</source>
        <translation>Aparença</translation>
    </message>
</context>
<context>
    <name>Proc</name>
    <message>
        <location filename="../proc.cpp" line="2850"/>
        <source>PID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2850"/>
        <source>Process ID</source>
        <translation>ID procés</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2852"/>
        <source>TGID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2852"/>
        <source>Task group ID ( parent of threads )</source>
        <translation>ID de grup de tasques ( pare dels fils )</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2854"/>
        <source>PPID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2854"/>
        <source>Parent process ID</source>
        <translation>ID de procés pare</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2856"/>
        <source>PGID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2856"/>
        <source>Process group ID</source>
        <translation>ID de grup de processos</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2858"/>
        <source>SID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2858"/>
        <source>Session ID</source>
        <translation>ID de sessió</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2860"/>
        <source>TTY</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2860"/>
        <source>Terminal</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2862"/>
        <source>TPGID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2862"/>
        <source>Process group ID of tty owner</source>
        <translation>ID de grup de processos del propietari del tty</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2864"/>
        <source>USER</source>
        <translation>USUARI</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2864"/>
        <source>Owner (*=suid root, +=suid a user)</source>
        <translation>Propietari (*=suid root, +=suid un usuari)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2866"/>
        <source>GROUP</source>
        <translation>GRUP</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2866"/>
        <source>Group name (*=sgid other)</source>
        <translation>Nom de grup (*=sgid altres)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2868"/>
        <source>UID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2868"/>
        <source>Real user ID</source>
        <translation>ID d&apos;usuari real</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2870"/>
        <source>EUID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2870"/>
        <source>Effective user ID</source>
        <translation>ID d&apos;usuari efectiu</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2872"/>
        <source>SUID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2872"/>
        <source>Saved user ID (Posix)</source>
        <translation>ID d&apos;usuari desat (Posix)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2874"/>
        <source>FSUID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2874"/>
        <source>File system user ID</source>
        <translation>ID d&apos;usuari de sistema de fitxers</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2876"/>
        <source>GID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2876"/>
        <source>Real group ID</source>
        <translation>ID de grup real</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2878"/>
        <source>EGID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2878"/>
        <source>Effective group ID</source>
        <translation>ID de grup efectiu</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2880"/>
        <source>SGID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2880"/>
        <source>Saved group ID (Posix)</source>
        <translation>ID de grup desat (Posix)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2882"/>
        <source>FSGID</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2882"/>
        <source>File system group ID</source>
        <translation>ID de grup de sistemes de fitxers</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2884"/>
        <source>PRI</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2884"/>
        <source>Dynamic priority</source>
        <translation>Prioritat dinàmica</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2886"/>
        <source>NICE</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2886"/>
        <source>Scheduling favour (higher -&gt; less cpu time)</source>
        <translation>A favor de la planificació (més alt -&gt; menys temps de CPU)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2888"/>
        <source>NLWP</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2888"/>
        <source>Number of tasks(threads) in task group</source>
        <translation>Nombre de tasques(fils) al grup de tasques</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2890"/>
        <source>PLCY</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2890"/>
        <source>Scheduling policy</source>
        <translation>Política de planificació</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2892"/>
        <source>RPRI</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2892"/>
        <source>Realtime priority (0-99, more is better)</source>
        <translation>Prioritat de temps real (0-99, més és millor)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2894"/>
        <source>TMS</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2894"/>
        <source>Time slice in milliseconds</source>
        <translation>Porció de temps en mil·lisegons</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2896"/>
        <source>%SAVG</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2896"/>
        <source>Percentage average sleep time (-1 -&gt; N/A)</source>
        <translation>Percentatge mitjà de temps d&apos;adormiment (-1 -&gt; N/D)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2898"/>
        <source>CPUSET</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2898"/>
        <source>Affinity CPU mask (0 -&gt; API not supported)</source>
        <translation>Màscara de CPU d&apos;afinitat (0 -&gt; API no admesa)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2900"/>
        <source>MAJFLT</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2900"/>
        <source>Number of major faults (disk access)</source>
        <translation>Nombre de falles major (accés de disc)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2902"/>
        <source>MINFLT</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2902"/>
        <source>Number of minor faults (no disk access)</source>
        <translation>Nombre de falles menor (sense accés de disc)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2905"/>
        <source>VSIZE</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2905"/>
        <source>Virtual image size of process</source>
        <translation>Mida d&apos;imatge virtual del procés</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2907"/>
        <source>RSS</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2907"/>
        <source>Resident set size</source>
        <translation>Mida d&apos;establiment resident</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2909"/>
        <source>MEM</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2909"/>
        <source>memory usage (RSS-SHARE)</source>
        <translation>ús de memòria (RSS-SHARE)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2911"/>
        <source>TRS</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2911"/>
        <source>Text(code) resident set size</source>
        <translation>Mida d&apos;establiment resident de Text(code)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2913"/>
        <source>DRS</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2913"/>
        <source>Data resident set size(malloc+global variable)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2915"/>
        <source>STACK</source>
        <translation>PILA</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2915"/>
        <source>Stack size</source>
        <translation>Mida de pila</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2917"/>
        <source>SHARE</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2917"/>
        <source>Shared memory with other libs</source>
        <translation>Memòria compartida amb altres biblioteques</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2919"/>
        <source>SWAP</source>
        <translation>INTERCANI</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2919"/>
        <source>Kbytes on swap device</source>
        <translation>Kbytes al dispositiu d&apos;intercanvi</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2921"/>
        <source>IO_R</source>
        <translation>ES_L</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2921"/>
        <source>io read (file)</source>
        <translation>lectura e/s (fitxer)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2923"/>
        <source>IO_W</source>
        <translation>ES_E</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2923"/>
        <source>io write (file)</source>
        <translation>escriptura e/s (fitxer)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2925"/>
        <source>DT</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2925"/>
        <source>Number of dirty (non-written) pages</source>
        <translation>Nombre de pàgines brutes (no escrites)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2927"/>
        <source>STAT</source>
        <translation>ESTAT</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2927"/>
        <source>State of the process </source>
        <translation>Estat del procés </translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2929"/>
        <source>FLAGS</source>
        <translation>INDICADORS</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2929"/>
        <source>Process flags (hex)</source>
        <translation>Indicadors de procés (hex)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2931"/>
        <source>WCHAN</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2931"/>
        <source>Kernel function where process is sleeping</source>
        <translation>Funció del Kernel on el procés està dormint</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2933"/>
        <source>%WCPU</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2933"/>
        <source>Weighted percentage of CPU (30 s average)</source>
        <translation>Percentatge ponderat de CPU (mitjana de 30 s)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2935"/>
        <source>%CPU</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2935"/>
        <source>Percentage of CPU used since last update</source>
        <translation>Percentatge de CPU utilitzat des de l&apos;última actualització</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2937"/>
        <source>%MEM</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2937"/>
        <source>Percentage of memory used (RSS/total mem)</source>
        <translation>Percentatge utilitzat de memòria (RSS/total mem)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2939"/>
        <source>START</source>
        <translation>INICI</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2939"/>
        <source>Time process started</source>
        <translation>L&apos;hora en què es va iniciar el procés</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2941"/>
        <source>TIME</source>
        <translation>TEMPS</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2941"/>
        <source>Total CPU time used since start</source>
        <translation>Temps de CPU total que s&apos;ha utilitzat des de que es va iniciar</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2943"/>
        <source>CPU</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2943"/>
        <source>CPU the process is executing on (SMP system)</source>
        <translation>CPU en què s&apos;està executant el procés (sistema SMP)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2945"/>
        <source>the process name</source>
        <translation>el nom del procés</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2945"/>
        <source>Process Name</source>
        <translation>Nom del procés</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2949"/>
        <source>CWD</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2949"/>
        <source>Current working directory</source>
        <translation>Directori actual de treball</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2950"/>
        <source>ROOT</source>
        <translation>ARREL</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2950"/>
        <source>Root directory of process</source>
        <translation>Directori arrel del procés</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2953"/>
        <source>COMMAND_LINE</source>
        <translation>LÍNEA_ORDRE</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2953"/>
        <source>Command line that started the process</source>
        <translation>Línia de l&apos;ordre que va iniciar el procés</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../qps.cpp" line="1845"/>
        <source>Show</source>
        <translation>Mostra</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1848"/>
        <source>Hide</source>
        <translation>Oculta</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1852"/>
        <source>Quit</source>
        <translation>Surt</translation>
    </message>
</context>
<context>
    <name>Qps</name>
    <message>
        <location filename="../qps.cpp" line="198"/>
        <source>header_popup</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="199"/>
        <source>Remove Field</source>
        <translation>Suprimeix el camp</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="200"/>
        <source>Add Field</source>
        <translation>Afegeix un camp</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="207"/>
        <source>View</source>
        <translation>Visualitza</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="208"/>
        <source>Process</source>
        <translation>Procés</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="209"/>
        <source>Log</source>
        <translation>Registre</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="214"/>
        <source>Fields</source>
        <translation>Camps</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="215"/>
        <source>Custom Fields</source>
        <translation>Camps personalitzats</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="217"/>
        <source>Basic Fields </source>
        <translation>Camps bàsics </translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="219"/>
        <source>Jobs Fields </source>
        <translation>Camps dels treballs </translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="221"/>
        <source>Memory Fields </source>
        <translation>Camps de la memòria </translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="224"/>
        <source>Scheduling Fields </source>
        <translation>Camps de la planificació </translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="241"/>
        <source>Select Custom Fields...</source>
        <translation>Selecciona els camps personalitzats...</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="203"/>
        <source>Command</source>
        <translation>Ordre</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="255"/>
        <source>Options</source>
        <translation>Opcions</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="256"/>
        <source>Update Period...</source>
        <translation>Període d&apos;actualització...</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="265"/>
        <source>Show Status bar</source>
        <translation>Mostra la barra d&apos;estat</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="274"/>
        <source>Preferences...</source>
        <translation>Preferències...</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="280"/>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="282"/>
        <location filename="../qps.cpp" line="1893"/>
        <source>About</source>
        <translation>Quant a</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="370"/>
        <source>Detail</source>
        <translation>Detallat</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="411"/>
        <source>test</source>
        <translation>prova</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="412"/>
        <source>Copied to Clipboard</source>
        <translation>S&apos;ha copiat al porta-retalls</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="464"/>
        <source>context popup</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="465"/>
        <source>Renice...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="466"/>
        <source>Scheduling...</source>
        <translation>Planificació...</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="468"/>
        <source>Terminate</source>
        <translation>Termina</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="470"/>
        <source>Hangup</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="471"/>
        <source>Kill</source>
        <translation>Mata</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="472"/>
        <source>Stop</source>
        <translation>Atura</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="474"/>
        <source>Continue</source>
        <translation>Continua</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="477"/>
        <source>Other Signals</source>
        <translation>Altres senyals</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="478"/>
        <source>SIGINT (interrupt)</source>
        <translation>SIGINT (interromp)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="480"/>
        <source>SIGCONT (continue)</source>
        <translation>SIGCONT (continua)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="482"/>
        <source>SIGSTOP (stop)</source>
        <translation>SIGSTOP (atura)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="484"/>
        <source>SIGQUIT (quit)</source>
        <translation>SIGQUIT (surt)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="486"/>
        <source>SIGILL (illegal instruction)</source>
        <translation>SIGILL (instrucció il·legal)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="488"/>
        <source>SIGABRT (abort)</source>
        <translation>SIGABRT (avorta)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="490"/>
        <source>SIGFPE (floating point exception)</source>
        <translation>SIGFPE (excepció de punt flotant)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="492"/>
        <source>SIGSEGV (segmentation violation)</source>
        <translation>SIGSEGV (violació de la segmentació)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="494"/>
        <source>SIGPIPE (broken pipe)</source>
        <translation>SIGPIPE (canonada trencada)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="496"/>
        <source>SIGALRM (timer signal)</source>
        <translation>SIGALRM (senyal del temporitzador)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="498"/>
        <source>SIGUSR1 (user-defined 1)</source>
        <translation>SIGUSR1 (definida de l&apos;usuari 1)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="500"/>
        <source>SIGUSR2 (user-defined 2)</source>
        <translation>SIGUSR2 (definida de l&apos;usuari 2)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="502"/>
        <source>SIGCHLD (child death)</source>
        <translation>SIGCHLD (mort del fill)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="504"/>
        <source>SIGTSTP (stop from tty)</source>
        <translation>SIGTSTP (aturada des del tty)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="506"/>
        <source>SIGTTIN (tty input)</source>
        <translation>SIGTTIN (entrada tty)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="508"/>
        <source>SIGTTOU (tty output)</source>
        <translation>SIGTTOU (sortida tty)</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="515"/>
        <source>View Details</source>
        <translation>Mostra els detalls</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="781"/>
        <source>Show File Path</source>
        <translation>Mostra el camí del fitxer</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="787"/>
        <source>Show Graph</source>
        <translation>Mostra el gràfic</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="793"/>
        <source>Show Control Bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="804"/>
        <source>Include Child Times</source>
        <translation>Inclou els temps dels processos fills</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="998"/>
        <source>WatchDog</source>
        <translation>Vigilant</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1000"/>
        <source>Edit Commands...</source>
        <translation>Edita les ordres...</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1016"/>
        <source>Quit</source>
        <translation>Surt</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1335"/>
        <location filename="../qps.cpp" line="1366"/>
        <location filename="../qps.cpp" line="1373"/>
        <location filename="../qps.cpp" line="1394"/>
        <location filename="../qps.cpp" line="1428"/>
        <location filename="../qps.cpp" line="1523"/>
        <source>Permission denied</source>
        <translation>Permís denegat</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1336"/>
        <source>You do not have permission to renice the selected processes. Only the process owner and the super-user are allowed to do that.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1367"/>
        <source>You do not have permission to renice process %1 (%2).Only the process owner and the super-user are allowed to do that.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1374"/>
        <source>Only the super-user may lower the nice value of a process.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1395"/>
        <source>Only the super-user may change the scheduling policy and static priority.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1429"/>
        <source>You do not have permission to change the scheduling and/or priority of process %1 (%2). Only the super-user may do that.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1490"/>
        <source>Do you really want to terminate the selected process(es)?</source>
        <translation>Realment voleu finalitzar els processos seleccionats?</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1492"/>
        <source>Do you really want to hang up the selected process(es)?</source>
        <translation>Realment voleu penjar els processos seleccionats?</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1494"/>
        <source>Do you really want to kill the selected process(es)?</source>
        <translation>Realment voleu matar els processos seleccionats?</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1503"/>
        <source>Question</source>
        <translation>Pregunta</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1524"/>
        <source>You do not have permission to send a signal to process %1 (%2). Only the super-user and the owner of the process may send signals to it.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1909"/>
        <source>&lt;center&gt;&lt;h2&gt; Qps %1&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;h2&gt; Qps %1&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1911"/>
        <source>&lt;h2&gt; Qps %1 - A Visual Process Manager &lt;/h2&gt; %2 using Qt library %3&lt;br&gt;&lt;br&gt;&lt;b&gt;Source: &lt;/b&gt;&lt;a href=&quot;https://github.com/lxqt/qps&quot;&gt;https://github.com/lxqt/qps/&lt;/a&gt;&lt;br&gt;&lt;b&gt;Bugtracker: &lt;/b&gt;&lt;a href=&quot;https://github.com/lxqt/qps/issues&quot;&gt;https://github.com/lxqt/qps/issues&lt;/a&gt;&lt;br&gt;</source>
        <translation>&lt;h2&gt; Qps %1 - Un gestor de processos visuals &lt;/h2&gt; %2 que utilitza la font %3&lt;br&gt;&lt;br&gt;&lt;b&gt;de la biblioteca Qt: &lt;/b&gt;&lt;a href=&quot;https://github.com/lxqt/qps&quot;&gt;https://github.com/lxqt/qps/&lt;/a&gt;&lt;br&gt;&lt;b&gt;Seguidor d&apos;errors: &lt;/b&gt;&lt;a href=&quot;https://github.com/lxqt/qps/issues&quot;&gt;https://github.com/lxqt/qps/issues&lt;/a&gt;&lt;br&gt;</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1931"/>
        <source>&lt;b&gt;Original Qps by&lt;/b&gt;&lt;br&gt;Mattias Engdegård (f91-men@nada.kth.se)&lt;br&gt;&lt;br&gt;&lt;b&gt;Contributors&lt;/b&gt;&lt;br&gt;Olivier.Daudel@u-paris10.fr&lt;br&gt;jsanchez@todounix.homeip.net &lt;br&gt;daehyun.yang@gmail.com &lt;br&gt;Luís Pereira (luis.artur.pereira@gmail.com)&lt;br&gt;Alf Gaida (agaida@siduction.org)&lt;br&gt;Paulo Lieuthier (paulolieuthier@gmail.com)&lt;br&gt;Jerome Leclanche (jerome@leclan.ch)&lt;br&gt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1969"/>
        <source>&lt;H1&gt;QPS Help&lt;/H1&gt;Updated: May 24 2005&lt;BR&gt;&lt;A HREF=&quot;http://kldp.net/projects/qps&quot;&gt;http://kldp.net/projects/qps&lt;/A&gt;&lt;HR&gt;&lt;table style=&quot;text-align: center; width: 100%;&quot; border=&quot;1&quot; cellpadding=&quot;1&quot; cellspacing=&quot;0&quot;&gt;  &lt;tbody&gt;    &lt;tr&gt;      &lt;td style=&quot;vertical-align: top; background-color: rgb(204, 204, 204);&quot;&gt;Quit      &lt;/td&gt;      &lt;td &gt;&amp;nbsp; CTRL + q , CTRL + x      &lt;/td&gt;    &lt;/tr&gt;    &lt;tr&gt;      &lt;td style=&quot;vertical-align: top; background-color: rgb(204, 204, 204);&quot;&gt;Update      &lt;/td&gt;      &lt;td&gt;&amp;nbsp;Space , Enter       &lt;/td&gt;    &lt;/tr&gt;    &lt;tr&gt;&lt;td&gt; process Terminate &lt;/td&gt;  &lt;td&gt; ALT + T , DELETE &lt;/td&gt; &lt;/tr&gt;    &lt;tr&gt;&lt;td&gt; process Kill &lt;/td&gt;  &lt;td&gt; ALT + K  &lt;/td&gt; &lt;/tr&gt;  &lt;/tbody&gt;&lt;/table&gt;</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>SchedDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="292"/>
        <source>Change scheduling</source>
        <translation>Canvia la planificació</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="296"/>
        <source>Scheduling Policy</source>
        <translation>Política de planificació</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="298"/>
        <source>SCHED_OTHER (time-sharing)</source>
        <translation>SCHED_OTHER (compartició del temps)</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="299"/>
        <source>SCHED_FIFO (real-time)</source>
        <translation>SCHED_FIFO (temps real)</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="300"/>
        <source>SCHED_RR (real-time)</source>
        <translation>SCHED_RR (temps real)</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="314"/>
        <source>OK</source>
        <translation>D&apos;acord</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="316"/>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="346"/>
        <source>Priority (1-99):</source>
        <translation>Prioritat (1-99):</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="379"/>
        <source>Invalid Input</source>
        <translation>Entrada no vàlida</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="380"/>
        <source>The priority must be in the range 1..99</source>
        <translation>La prioritat ha d&apos;estar dins de l&apos;interval 1..99</translation>
    </message>
</context>
<context>
    <name>SearchBox</name>
    <message>
        <location filename="../misc.cpp" line="712"/>
        <source>PID, COMMAND, USER...</source>
        <translation type="unfinished">IDENTIFICADOR DE PROCÉS, ORDRE, USUARI...</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="713"/>
        <source>Filter</source>
        <translation>Filtre</translation>
    </message>
</context>
<context>
    <name>SliderDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="179"/>
        <source>Renice Process</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="185"/>
        <source>New nice value:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="225"/>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="229"/>
        <source>OK</source>
        <translation>D&apos;acord</translation>
    </message>
</context>
<context>
    <name>Sockets</name>
    <message>
        <location filename="../details.cpp" line="147"/>
        <source>Fd</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../details.cpp" line="147"/>
        <source>File descriptor</source>
        <translation>Descriptor de fitxer</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="148"/>
        <source>Proto</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../details.cpp" line="148"/>
        <source>Protocol (TCP or UDP)</source>
        <translation>Protocol (TCP o UDP)</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="149"/>
        <source>Recv-Q</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../details.cpp" line="149"/>
        <source>Bytes in receive queue</source>
        <translation>Bytes a la cua de recepció</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="150"/>
        <source>Send-Q</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../details.cpp" line="150"/>
        <source>Bytes in send queue</source>
        <translation>Bytes a la cua d&apos;enviament</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="151"/>
        <source>Local Addr</source>
        <translation>Adreça local</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="151"/>
        <source>Local IP address</source>
        <translation>Adreça IP local</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="152"/>
        <location filename="../details.cpp" line="154"/>
        <source>Port</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../details.cpp" line="152"/>
        <source>Local port</source>
        <translation>Port local</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="153"/>
        <source>Remote Addr</source>
        <translation>Adreça remota</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="153"/>
        <source>Remote IP address</source>
        <translation>Adreça IP remota</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="154"/>
        <source>Remote port</source>
        <translation>Port remot</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="155"/>
        <source>State</source>
        <translation>Estat</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="155"/>
        <source>Connection state</source>
        <translation>Estat de la connexió</translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <location filename="../misc.cpp" line="748"/>
        <source>Process count: %1</source>
        <translation>Nombre de processos: %1</translation>
    </message>
</context>
<context>
    <name>TBloon</name>
    <message>
        <location filename="../misc.cpp" line="347"/>
        <source> This is unstable Alpha feature
 You maybe see a SEGFAULT...</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>TFrame</name>
    <message>
        <location filename="../misc.cpp" line="426"/>
        <source>this is Tframe widget</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>UFrame</name>
    <message>
        <location filename="../misc.cpp" line="610"/>
        <source>title</source>
        <translation>títol</translation>
    </message>
</context>
<context>
    <name>WatchdogDialog</name>
    <message>
        <location filename="../watchdogdialog.cpp" line="191"/>
        <source>if process start</source>
        <translation>si s&apos;inicia el procés</translation>
    </message>
    <message>
        <location filename="../watchdogdialog.cpp" line="192"/>
        <source>if process finish</source>
        <translation>si s&apos;acaba el procés</translation>
    </message>
    <message>
        <location filename="../watchdogdialog.cpp" line="215"/>
        <source>select condition</source>
        <translation>seleccioneu la condició</translation>
    </message>
</context>
</TS>
